==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/de.js <==
/**
 * German
 */

$.Editable.LANGS['de'] = {
  translation: {
    "Bold": "Fett",
    "Italic": "Kursiv",
    "Underline": "Unterstrichen",
    "Strikethrough": "Durchgestrichen",
    "Font Size": "Schriftgr\u00f6\u00dfe",
    "Color": "Farbe",
    "Background Color": "Hintergrundfarbe",
    "Text Color": "Textfarbe",
    "Format Block": "Formate",
    "Normal": "Normal",
    "Paragraph": "Absatz",
    "Code": "Quelltext",
    "Quote": "Zitat",
    "Heading 1": "\u00dcberschrift 1",
    "Heading 2": "\u00dcberschrift 2",
    "Heading 3": "\u00dcberschrift 3",
    "Heading 4": "\u00dcberschrift 4",
    "Heading 5": "\u00dcberschrift 5",
    "Heading 6": "\u00dcberschrift 6",
    "Alignment": "Ausrichtung",
    "Align Left": "Linksb\u00fcndig ausrichten",
    "Align Center": "Zentriert ausrichten",
    "Align Right": "Rechtsb\u00fcndig ausrichten",
    "Justify": "Blocksatz",
    "Numbered List": "Nummerierte Liste",
    "Bulleted List": "Aufz\u00e4hlung",
    "Indent Less": "Einzug verkleinern",
    "Indent More": "Einzug vergr\u00f6\u00dfern",
    "Select All": "Alles ausw\u00e4hlen",
    "Insert Link": "Link einf\u00fcgen",
    "Insert Image": "Bild einf\u00fcgen",
    "Insert Video": "Video einf\u00fcgen",
    "Undo": "R\u00fcckg\u00e4ngig",
    "Redo": "Wiederholen",
    "Show HTML": "HTML anzeigen",
    "Float Left": "Linksb\u00fcndig",
    "Float None": "Keine",
    "Float Right": "Rechtsb\u00fcndig",
    "Replace Image": "Bild ersetzen",
    "Remove Image": "Bild entfernen",
    "Title": "Titel",
    "Insert image": "Bild einf\u00fcgen",
    "Drop image": "Ziehen Sie ein Bild hierhin",
    "or click": "oder klicken Sie auf",
    "Enter URL": "URL eingeben",
    "Please wait!": "Bitte warten Sie!",
    "Are you sure? Image will be deleted.": "Sind Sie sicher? Das Bild wird gel\u00f6scht.",
    "UNLINK": "Link entfernen",
    "Open in new tab": "In neuer Registerkarte \u00f6ffnen",
    "Type something": "Schreiben Sie etwas",
    "Cancel": "Abbrechen",
    "OK": "Ok",
    "Manage images": "Bilder verwalten",
    "Delete": "L\u00f6schen",
    "Font Family": "Schriftart",
    "Insert Horizontal Line": "Horizontale Linie Einf\u00fcgen"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.2.tar.gz: django-froala-editor-0.8.2/froala_editor/static/froala_editor/js/langs/de.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * German
 */

$.Editable.LANGS['de'] = {
  translation: {
    "Bold": "Fett",
    "Italic": "Kursiv",
    "Underline": "Unterstrichen",
    "Strikethrough": "Durchgestrichen",
    "Font Size": "Schriftgr\u00f6\u00dfe",
    "Color": "Farbe",
    "Background Color": "Hintergrundfarbe",
    "Text Color": "Textfarbe",
    "Format Block": "Formate",
    "Normal": "Normal",
    "Paragraph": "Absatz",
    "Code": "Quelltext",
    "Quote": "Zitat",
    "Heading 1": "\u00dcberschrift 1",
    "Heading 2": "\u00dcberschrift 2",
    "Heading 3": "\u00dcberschrift 3",
    "Heading 4": "\u00dcberschrift 4",
    "Heading 5": "\u00dcberschrift 5",
    "Heading 6": "\u00dcberschrift 6",
    "Alignment": "Ausrichtung",
    "Align Left": "Linksb\u00fcndig ausrichten",
    "Align Center": "Zentriert ausrichten",
    "Align Right": "Rechtsb\u00fcndig ausrichten",
    "Justify": "Blocksatz",
    "Numbered List": "Nummerierte Liste",
    "Bulleted List": "Aufz\u00e4hlung",
    "Indent Less": "Einzug verkleinern",
    "Indent More": "Einzug vergr\u00f6\u00dfern",
    "Select All": "Alles ausw\u00e4hlen",
    "Insert Link": "Link einf\u00fcgen",
    "Insert Image": "Bild einf\u00fcgen",
    "Insert Video": "Video einf\u00fcgen",
    "Undo": "R\u00fcckg\u00e4ngig",
    "Redo": "Wiederholen",
    "Show HTML": "HTML anzeigen",
    "Float Left": "Linksb\u00fcndig",
    "Float None": "Keine",
    "Float Right": "Rechtsb\u00fcndig",
    "Replace Image": "Bild ersetzen",
    "Remove Image": "Bild entfernen",
    "Title": "Titel",
    "Insert image": "Bild einf\u00fcgen",
    "Drop image": "Ziehen Sie ein Bild hierhin",
    "or click": "oder klicken Sie auf",
    "Enter URL": "URL eingeben",
    "Please wait!": "Bitte warten Sie!",
    "Are you sure? Image will be deleted.": "Sind Sie sicher? Das Bild wird gel\u00f6scht.",
    "UNLINK": "Link entfernen",
    "Open in new tab": "In neuer Registerkarte \u00f6ffnen",
    "Type something": "Schreiben Sie etwas",
    "Cancel": "Abbrechen",
    "OK": "Ok",
    "Manage images": "Bilder verwalten",
    "Delete": "L\u00f6schen",
    "Font Family": "Schriftart",
    "Insert Horizontal Line": "Horizontale Linie Einf\u00fcgen",
    "Table": "Tabelle",
    "Insert table": "Tabelle einf\u00fcgen",
    "Cell": "Zelle",
    "Row": "Zeile",
    "Column": "Spalte",
    "Delete table": "Tabelle l\u00f6schen",
    "Insert cell before": "Neue zelle davor einf\u00fcgen",
    "Insert cell after": "Neue zelle danach einf\u00fcgen",
    "Delete cell": "Zelle l\u00f6schen",
    "Merge cells": "Zelle verschmelzen",
    "Horizontal split": "Horizontal aufteilung",
    "Vertical split": "Vertikal aufteilung",
    "Insert row above": "Neue Zeile davor einf\u00fcgen",
    "Insert row below": "Neue Zeile danach einf\u00fcgen",
    "Delete row": "Zeile l\u00f6schen",
    "Insert column before": "Neue Spalte davor einf\u00fcgen",
    "Insert column after": "Neue Spalte danach einf\u00fcgen",
    "Delete column": "Spalte l\u00f6schen"
  },
  direction: "ltr"
};
